@@ -14,7 +14,6 @@ from sensenet.layers.tree import ForestPreprocessor
 from sensenet.load import load_points
 from sensenet.models.wrappers import create_model
 from sensenet.models.settings import Settings
-from sensenet.io.save import assets_for_deepnet, write_model
 
 from .utils import TEST_DATA_DIR, read_regression
 
@@ -29,7 +28,7 @@ TEMP_WEIGHTS = os.path.join(TEST_DATA_DIR, 'test_save_weights.h5')
 TEMP_BUNDLE = os.path.join(TEST_DATA_DIR, 'test_save_bundle.smbundle')
 TEMP_TFJS = os.path.join(TEST_DATA_DIR, 'test_save_tfjs')
 
-EXTRA_PARAMS = Settings({'image_path_prefix': TEST_DATA_DIR + 'images/digits/'})
+EXTRA_PARAMS = Settings({})
 
 def remove_temp_files():
     for afile in [TEMP_WEIGHTS, TEMP_BUNDLE]:
